@@ -160,6 +160,12 @@ async def eth_chainId():
     return "0x52"
 
 
+@method
+@async_serialize
+async def eth_gasPrice():
+    return hex(int(500e9))  # default gas price set to 500 GWei
+
+
 @method
 @async_serialize
 async def eth_getTransactionCount(address, block_identifier="best"):
